[![GitHub version](https://badge.fury.io/gh/ornlneutronimaging%2FBraggEdge.svg)](https://badge.fury.io/gh/ornlneutronimaging%2FBraggEdge)
[![Build Status](https://travis-ci.org/ornlneutronimaging/BraggEdge.svg?branch=master)](https://travis-ci.org/ornlneutronimaging/BraggEdge)
[![codecov.io](https://codecov.io/github/ornlneutronimaging/BraggEdge/coverage.svg?branch=master)](https://codecov.io/github/ornlneutronimaging/BraggEdge?branch=master)
[![Join the chat at https://gitter.im/ornlneutronimaging](https://badges.gitter.im/Join%20Chat.svg)](https://gitter.im/ornlneutronimaging?utm_source=share-link&utm_medium=link&utm_campaign=share-link)
[![Documentation Status](https://readthedocs.org/projects/braggedge/badge/?version=latest)](http://braggedge.readthedocs.io/en/latest/?badge=latest)

# BraggEdge
Work concerning the Bragg Edge LDRD (check the documentation for more details)

# Tests
to run the tests
> nosetests -v --rednose --with-coverage --cover-package=python.neutronbraggedge --cover-html

# Documentation
to build the documentation
> cd docs

> make html

to visualize the documentation, via a browser, open
> docs/_build/html/index.hmtl

or on the web 
http://ornlneutronimaging.github.io/BraggEdge/
